@@ -7,11 +7,12 @@ from pyhafas.types.hafas_response import HafasResponse
 
 class LocationRequestInterface(abc.ABC):
     @abc.abstractmethod
-    def format_location_request(self, term: str):
+    def format_location_request(self, term: str, rtype: str = 'S'):
         """
         Creates the HaFAS request body for a location search request.
 
         :param term: Search term
+        :param rtype: Result types. One of ['S' for stations, 'ALL' for addresses and stations]
         :return: Request body for HaFAS
         """
         pass
